@@ -2,7 +2,7 @@
 #include <Python.h>
 #include <stdlib.h>
 #include <string.h>
-#include <timsort/llistobject.h>
+#include <llistobject.h>
 
 int Get_minrun(char path[], int size_of_array)
 {
